{
 "metadata": {
  "name": "",
  "signature": "sha256:c64513d51aea202961c0914be9618795e79da161eedae4bdb2632021c52e207a"
 },
 "nbformat": 3,
 "nbformat_minor": 0,
 "worksheets": [
  {
   "cells": [
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "%matplotlib inline\n",
      "import numpy as np\n",
      "import numpy.random as rnd\n",
      "import matplotlib.pyplot as plt #, mpld3\n",
      "plt.rcParams['figure.figsize'] = 12, 8\n",
      "#mpld3.enable_notebook()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 15
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "class Ising2D:\n",
      "    def __init__(self, (Lx, Ly), (Jx, Jy), beta, local=False):\n",
      "        self.Lx = Lx\n",
      "        self.Ly = Ly\n",
      "        self.Jx = Jx\n",
      "        self.Jy = Jy\n",
      "        self.beta = beta\n",
      "        self.local = local\n",
      "        self.config = 2*rnd.randint(2, size=(Ly, Lx)) - 1\n",
      "    \n",
      "    def run(self, num_thermal_steps, num_sample_steps):\n",
      "        self.m_abs = np.zeros(num_sample_steps)\n",
      "        self.m_sqr = np.zeros(num_sample_steps)\n",
      "        acceptance_ratio = 0\n",
      "        for _ in range(num_thermal_steps):\n",
      "            self.step()\n",
      "        for idx in range(num_sample_steps):\n",
      "            acceptance_ratio += self.step()\n",
      "            self.sample(idx)\n",
      "        return acceptance_ratio / float(num_sample_steps)\n",
      "    \n",
      "    def step(self):\n",
      "        if self.local:\n",
      "            return self.local_step()\n",
      "        return self.cluster_step()\n",
      "    \n",
      "    def local_step(self):\n",
      "        accepted = 0\n",
      "        for _ in range(self.Lx*self.Ly):\n",
      "            x, y = self.randsite()\n",
      "            old = self.config[y, x]\n",
      "            left = self.config[y, (x-1) % self.Lx]\n",
      "            right = self.config[y, (x+1) % self.Lx]\n",
      "            up = self.config[(y-1) % self.Ly, x]\n",
      "            down = self.config[(y+1) % self.Ly, x]\n",
      "            delta_E = 2 * (self.Jx*left + self.Jx*right + self.Jy*up + self.Jy*down) * old\n",
      "            if rnd.random() <= np.exp(-self.beta*delta_E):\n",
      "                accepted += 1\n",
      "                self.config[y, x] = -self.config[y, x]\n",
      "        return accepted / float(self.Lx * self.Ly)\n",
      "    \n",
      "    def cluster_step(self):\n",
      "        x, y = self.randsite()\n",
      "        cluster = [(x, y)]\n",
      "        s = self.config[y, x]\n",
      "        self.config[y, x] = -s\n",
      "        todo = self.neighbors((x, y))\n",
      "        while todo:\n",
      "            J, (x, y) = todo.pop()\n",
      "            if self.config[y, x] != s:\n",
      "                continue\n",
      "            if (x, y) in cluster:\n",
      "                continue\n",
      "            if rnd.random() >= np.exp(-2*self.beta*J):\n",
      "                self.config[y, x] = -s\n",
      "                cluster += [(x, y)]\n",
      "                todo += self.neighbors((x, y))\n",
      "        return len(cluster)\n",
      "\n",
      "    def randsite(self):\n",
      "        return rnd.randint(self.Lx), rnd.randint(self.Ly)\n",
      "\n",
      "    def neighbors(self, (x, y)):\n",
      "        return [\n",
      "            (self.Jx, ((x-1) % self.Lx, y)),\n",
      "            (self.Jx, ((x+1) % self.Lx, y)),\n",
      "            (self.Jy, (x, (y-1) % self.Ly)),\n",
      "            (self.Jy, (x, (y+1) % self.Ly))\n",
      "        ]\n",
      "    \n",
      "    def sample(self, idx):\n",
      "        M = np.sum(self.config)\n",
      "        m = M / float(self.Lx * self.Ly)\n",
      "        self.m_abs[idx] = np.fabs(m)\n",
      "        self.m_sqr[idx] = m*m"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 2
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Test with known data for 1D Ising model: $J = 1, \\beta = 0.3$ should give $\\langle\\lvert m\\rvert\\rangle \\approx 0.24$"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "ising = Ising2D((1, 20), (0, 1), 0.3, local=True)\n",
      "print 'LOCAL:'\n",
      "print '  acceptance ratio =', ising.run(1000, 4096)\n",
      "print '  <|m|> =', np.average(ising.m_abs)\n",
      "\n",
      "ising = Ising2D((1, 20), (0, 1), 0.3, local=False)\n",
      "print 'CLUSTER:'\n",
      "print '  avg. cluster size =', ising.run(1000, 4096)\n",
      "print '  <|m|> =', np.average(ising.m_abs)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "LOCAL:\n",
        "  acceptance ratio = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "0.708312988281\n",
        "  <|m|> = 0.243090820313\n",
        "CLUSTER:\n",
        "  avg. cluster size = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "1.82006835938\n",
        "  <|m|> = 0.241870117188\n"
       ]
      }
     ],
     "prompt_number": 3
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def errors_binning(samples, min_bins=128):\n",
      "    l_max = int(round(np.log2(len(samples) / min_bins)))\n",
      "    assert min_bins * 2**l_max == len(samples)\n",
      "    errors = np.empty(l_max + 1)\n",
      "    for l in range(l_max + 1):\n",
      "        errors[l] = np.std(samples, ddof=1) / np.sqrt(len(samples))\n",
      "        samples = (samples[::2] + samples[1::2]) / 2.0\n",
      "    return errors\n",
      "\n",
      "def tau_int(errors):\n",
      "    return 0.5 * (errors[-1]**2 / errors[0]**2 - 1)\n",
      "\n",
      "def avg(samples):\n",
      "    \"\"\"returns triple (mean, error, autocorrelation time)\"\"\"\n",
      "    mean = np.average(samples)\n",
      "    errors = errors_binning(samples)\n",
      "    return mean, errors[-1], tau_int(errors)\n",
      "\n",
      "avg(ising.m_abs)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "metadata": {},
       "output_type": "pyout",
       "prompt_number": 4,
       "text": [
        "(0.24187011718750373, 0.0056166229046184556, 1.3885544223184922)"
       ]
      }
     ],
     "prompt_number": 4
    },
    {
     "cell_type": "heading",
     "level": 1,
     "metadata": {},
     "source": [
      "Classical 2D Ising"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "%%time\n",
      "Js = np.linspace(0.1, 1, 10)\n",
      "m_sqr_local = np.zeros((len(Js), 3))\n",
      "m_sqr_cluster = np.zeros((len(Js), 3))\n",
      "cluster_sizes = []\n",
      "L = 10\n",
      "for i, J in enumerate(Js):\n",
      "    print J\n",
      "    \n",
      "    ising = Ising2D((L, L), (J, J), beta=1, local=True)\n",
      "    print 'avg acceptance =', ising.run(1024, 4096)\n",
      "    m_sqr_local[i, :] = avg(ising.m_sqr)\n",
      "\n",
      "    ising = Ising2D((L, L), (J, J), beta=1, local=False)\n",
      "    cs = ising.run(1024, 4096)\n",
      "    print 'avg cluster size =', cs\n",
      "    m_sqr_cluster[i, :] = avg(ising.m_sqr)\n",
      "    cluster_sizes.append(cs)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "0.1\n",
        "avg acceptance = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "0.848618164063\n",
        "avg cluster size ="
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        " 1.55590820312\n",
        "0.2\n",
        "avg acceptance = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "0.691508789063\n",
        "avg cluster size ="
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        " 2.8486328125\n",
        "0.3\n",
        "avg acceptance = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "0.524836425781\n",
        "avg cluster size ="
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        " 6.9638671875\n",
        "0.4\n",
        "avg acceptance = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "0.303642578125\n",
        "avg cluster size ="
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        " 35.1789550781\n",
        "0.5\n",
        "avg acceptance = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "0.0784130859375\n",
        "avg cluster size ="
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        " 84.4919433594\n",
        "0.6\n",
        "avg acceptance = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "0.0262451171875\n",
        "avg cluster size ="
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        " 95.2746582031\n",
        "0.7\n",
        "avg acceptance = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "0.009853515625\n",
        "avg cluster size ="
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        " 97.9597167969\n",
        "0.8\n",
        "avg acceptance = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "0.0039453125\n",
        "avg cluster size ="
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        " 99.2927246094\n",
        "0.9\n",
        "avg acceptance = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "0.0015771484375\n",
        "avg cluster size ="
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        " 99.7456054688\n",
        "1.0\n",
        "avg acceptance = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "0.000673828125\n",
        "avg cluster size ="
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        " 99.8806152344\n",
        "Wall time: 2min 1s\n"
       ]
      }
     ],
     "prompt_number": 18
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "_, ax0 = plt.subplots()\n",
      "ax2 = ax0.twinx()\n",
      "ax0.set_title('Local vs. Cluster Updates')\n",
      "ax0.set_xlabel(r'$\\beta J$')\n",
      "ax0.set_ylabel(r'$\\langle m^2 \\rangle$')\n",
      "ax0.errorbar(Js, m_sqr_local[:,0], fmt='g.-', yerr=m_sqr_local[:,1], label='local')\n",
      "ax0.errorbar(Js, m_sqr_cluster[:,0], fmt='b.-', yerr=m_sqr_cluster[:,1], label='cluster')\n",
      "# ax2.set_ylabel(r'autocorrelation time $\\tau$')\n",
      "# ax2.plot(Js, m_sqr_local[:,2], 'g:')\n",
      "# ax2.plot(Js, m_sqr_cluster[:,2], 'b:')\n",
      "ax2.set_ylabel(r'avg. cluster size')\n",
      "ax2.plot(Js, cluster_sizes, 'r')\n",
      "ax0.legend()\n",
      "plt.show()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAvgAAAH8CAYAAACkW9toAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nIiKViAq+iIiIiEglooIvIiIiIlKJ/H8HkzIvlXXCvQAAAABJRU5ErkJggg==\n",
       "text": [
        "<matplotlib.figure.Figure at 0xb51fd30>"
       ]
      }
     ],
     "prompt_number": 19
    },
    {
     "cell_type": "heading",
     "level": 1,
     "metadata": {},
     "source": [
      "Quantum $\\mapsto$ Classical"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "%%time\n",
      "def quantum_1d_ising(L, M, J_over_Gamma, Delta):\n",
      "    J, Gamma = J_over_Gamma, 1.0\n",
      "    Jx = Delta * J\n",
      "    Jy = -0.5*np.log(Delta * Gamma)\n",
      "    return Ising2D((L, M), (Jx, Jy), beta=1)\n",
      "\n",
      "Js = np.linspace(0.5, 2, 5)\n",
      "Delta = 0.05\n",
      "colors = ['r', 'g', 'b', 'y']\n",
      "LMs = [8, 16, 24]\n",
      "betas = []\n",
      "m_abses = []\n",
      "for L in LMs:\n",
      "    M = L\n",
      "    print 'L = M =', L\n",
      "    betas.append(M * Delta)\n",
      "    m_abs = np.zeros((len(Js), 3))    \n",
      "    for i, J in enumerate(Js):\n",
      "        print '  J =', J\n",
      "        ising = quantum_1d_ising(L, M, J, Delta)\n",
      "        print '  -> avg. cluster size =', ising.run(1024, 4096)\n",
      "        m_abs[i, :] = avg(ising.m_abs)\n",
      "    m_abses.append(m_abs)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "L = M = 8\n",
        "  J = 0.5\n",
        "  -> avg. cluster size = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "11.0197753906\n",
        "  J = 0.875\n",
        "  -> avg. cluster size = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "14.7421875\n",
        "  J = 1.25\n",
        "  -> avg. cluster size = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "19.94921875\n",
        "  J = 1.625\n",
        "  -> avg. cluster size = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "26.572265625\n",
        "  J = 2.0\n",
        "  -> avg. cluster size = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "33.7612304688\n",
        "L = M = 16\n",
        "  J = 0.5\n",
        "  -> avg. cluster size = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "26.9194335938\n",
        "  J = 0.875\n",
        "  -> avg. cluster size = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "45.6176757812\n",
        "  J = 1.25\n",
        "  -> avg. cluster size = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "79.9128417969\n",
        "  J = 1.625\n",
        "  -> avg. cluster size = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "133.574707031\n",
        "  J = 2.0\n",
        "  -> avg. cluster size = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "189.163818359\n",
        "L = M = 24\n",
        "  J = 0.5\n",
        "  -> avg. cluster size = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "39.5415039062\n",
        "  J = 0.875\n",
        "  -> avg. cluster size = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "85.7145996094\n",
        "  J = 1.25\n",
        "  -> avg. cluster size = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "193.372558594\n",
        "  J = 1.625\n",
        "  -> avg. cluster size = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "387.088378906\n",
        "  J = 2.0\n",
        "  -> avg. cluster size = "
       ]
      },
      {
       "output_type": "stream",
       "stream": "stdout",
       "text": [
        "500.184082031\n",
        "Wall time: 3min 41s\n"
       ]
      }
     ],
     "prompt_number": 7
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "_, ax0 = plt.subplots()\n",
      "ax0.set_title('$|m|$')\n",
      "ax2 = ax0.twinx()\n",
      "ax0.set_xlabel(r'$\\beta J$')\n",
      "ax0.set_ylabel(r'$\\langle |m| \\rangle$')\n",
      "ax2.set_ylabel(r'autocorrelation time $\\tau$')\n",
      "for color, beta, m_abs in zip(colors, betas, m_abses):\n",
      "    ax0.errorbar(Js, m_abs[:,0], fmt=color + '.-', yerr=m_abs[:,1], label=r'$\\beta = %f$' % beta)\n",
      "    ax2.plot(Js, m_abs[:,2], color + ':')\n",
      "ax0.legend()\n",
      "plt.show()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAvgAAAH9CAYAAABvBwjNAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
       "text": [
        "<matplotlib.figure.Figure at 0xa67a9e8>"
       ]
      }
     ],
     "prompt_number": 17
    }
   ],
   "metadata": {}
  }
 ]
}